@@ -209,6 +209,14 @@ class MessageNotFound(NotFound):
     message = _("Message %(message_id)s could not be found.")
 
 
+class ResourceLockNotFound(NotFound):
+    message = _("Resource lock %(lock_id)s could not be found.")
+
+
+class ResourceVisibilityLockExists(ManilaException):
+    message = _("Resource %(resource_id)s is already locked.")
+
+
 class Found(ManilaException):
     message = _("Resource was found.")
     code = 302
@@ -284,8 +292,7 @@ class ShareDataCopyFailed(ManilaException):
 
 
 class ShareDataCopyCancelled(ManilaException):
-    message = _("Copy of contents from share instance %(src_instance)s "
-                "to share instance %(dest_instance)s was cancelled.")
+    message = _("Copy of contents from source to destination was cancelled.")
 
 
 class ServiceIPNotFound(ManilaException):
@@ -333,6 +340,10 @@ class HostBinaryNotFound(NotFound):
     message = _("Could not find binary %(binary)s on host %(host)s.")
 
 
+class TransferNotFound(NotFound):
+    message = _("Transfer %(transfer_id)s could not be found.")
+
+
 class InvalidReservationExpiration(Invalid):
     message = _("Invalid reservation expiration %(expire)s.")
 
@@ -493,6 +504,10 @@ class InvalidShare(Invalid):
     message = _("Invalid share: %(reason)s.")
 
 
+class InvalidAuthKey(Invalid):
+    message = _("Invalid auth key: %(reason)s")
+
+
 class ShareBusyException(Invalid):
     message = _("Share is busy with an active task: %(reason)s.")
 
@@ -531,6 +546,10 @@ class ShareSnapshotAccessExists(InvalidInput):
     message = _("Share snapshot access %(access_type)s:%(access)s exists.")
 
 
+class InvalidSnapshot(Invalid):
+    message = _("Invalid snapshot: %(reason)s")
+
+
 class InvalidSnapshotAccess(Invalid):
     message = _("Invalid access rule: %(reason)s")
 
@@ -547,6 +566,10 @@ class InvalidShareAccessType(Invalid):
     message = _("Invalid or unsupported share access type: %(type)s.")
 
 
+class DriverCannotTransferShareWithRules(ManilaException):
+    message = _("Driver failed to transfer share with rules.")
+
+
 class ShareBackendException(ManilaException):
     message = _("Share backend error: %(msg)s.")
 
@@ -1131,3 +1154,31 @@ class ZadaraServerNotFound(NotFound):
 # Macrosan Storage driver
 class MacrosanBackendExeption(ShareBackendException):
     message = _("Macrosan backend exception: %(reason)s")
+
+
+# Backup
+class BackupException(ManilaException):
+    message = _("Unable to perform a backup action: %(reason)s.")
+
+
+class InvalidBackup(Invalid):
+    message = _("Invalid backup: %(reason)s.")
+
+
+class BackupLimitExceeded(QuotaError):
+    message = _("Maximum number of backups allowed (%(allowed)d) exceeded.")
+
+
+class ShareBackupNotFound(NotFound):
+    message = _("Backup %(backup_id)s could not be found.")
+
+
+class ShareBackupSizeExceedsAvailableQuota(QuotaError):
+    message = _("Requested backup exceeds allowed Backup gigabytes "
+                "quota. Requested %(requested)sG, quota is %(quota)sG and "
+                "%(consumed)sG has been consumed.")
+
+
+class NetappActiveIQWeigherRequiredParameter(ManilaException):
+    message = _("%(config)s configuration of the NetAppActiveIQ weigher "
+                "must be set.")
