@@ -65,14 +65,12 @@ class FakeConnection(base.StorageConnection):
 
     def connect(self, emc_share_driver, context):
         """Any initialization the share driver does while starting."""
-        raise NotImplementedError()
 
     def update_share_stats(self, stats_dict):
         """Add key/values to stats_dict."""
 
     def get_network_allocations_number(self):
         """Returns number of network allocations for creating VIFs."""
-        return 0
 
     def setup_server(self, network_info, metadata=None):
         """Set up and configures share server with given network parameters."""
@@ -81,7 +79,23 @@ class FakeConnection(base.StorageConnection):
         """Teardown share server."""
 
 
+class FakeConnection_vmax(FakeConnection):
+    def __init__(self, *args, **kwargs):
+        self.dhss_mandatory_security_service_association = {}
+        self.revert_to_snap_support = False
+        self.shrink_share_support = False
+        self.manage_existing_support = False
+        self.manage_existing_with_server_support = False
+        self.manage_existing_snapshot_support = False
+        self.manage_snapshot_with_server_support = False
+        self.manage_server_support = False
+        self.get_share_server_network_info_support = False
+        pass
+
+
 FAKE_BACKEND = 'fake_backend'
+FAKE_BACKEND_VMAX = 'vmax'
+FAKE_BACKEND_POWERMAX = 'powermax'
 
 
 class FakeEMCExtensionManager(object):
@@ -92,6 +106,11 @@ class FakeEMCExtensionManager(object):
                                 plugin=FakeConnection,
                                 entry_point=None,
                                 obj=None))
+        self.extensions.append(
+            extension.Extension(name=FAKE_BACKEND_POWERMAX,
+                                plugin=FakeConnection_vmax,
+                                entry_point=None,
+                                obj=None))
 
 
 class EMCShareFrameworkTestCase(test.TestCase):
@@ -107,6 +126,15 @@ class EMCShareFrameworkTestCase(test.TestCase):
         self.driver = emcdriver.EMCShareDriver(
             configuration=self.configuration)
 
+        self.configuration_vmax = conf.Configuration(None)
+        self.configuration_vmax.append_config_values = \
+            mock.Mock(return_value=0)
+        self.configuration_vmax.share_backend_name = FAKE_BACKEND_VMAX
+        self.mock_object(self.configuration_vmax, 'safe_get',
+                         self._fake_safe_get_vmax)
+        self.driver_vmax = emcdriver.EMCShareDriver(
+            configuration=self.configuration_vmax)
+
     def test_driver_setup(self):
         FakeConnection.connect = mock.Mock()
         self.driver.do_setup(None)
@@ -157,6 +185,13 @@ class EMCShareFrameworkTestCase(test.TestCase):
             return True
         return None
 
+    def _fake_safe_get_vmax(self, value):
+        if value in ['emc_share_backend', 'share_backend_name']:
+            return FAKE_BACKEND_VMAX
+        elif value == 'driver_handles_share_servers':
+            return True
+        return None
+
     def test_support_manage(self):
         share = mock.Mock()
         driver_options = mock.Mock()
@@ -179,6 +214,33 @@ class EMCShareFrameworkTestCase(test.TestCase):
                                                          share_server)
         self.driver.manage_server(context, share_server, identifier,
                                   driver_options)
+        self.driver.get_share_server_network_info_support = True
+        self.driver.get_share_server_network_info(context, share_server,
+                                                  identifier, driver_options)
+        self.driver.create_share(context, share, share_server)
+        self.driver.create_share_from_snapshot(context, share, snapshot,
+                                               share_server)
+        self.driver.extend_share(share, 20, share_server)
+        self.driver.shrink_share_support = True
+        self.driver.shrink_share(share, 20, share_server)
+        self.driver.create_snapshot(context, snapshot, share_server)
+        self.driver.delete_share(context, share, share_server)
+        self.driver.delete_snapshot(context, snapshot, share_server)
+        self.driver.ensure_share(context, share, share_server)
+        access = mock.Mock()
+        self.driver.allow_access(context, share, access, share_server)
+        self.driver.deny_access(context, share, access, share_server)
+        self.driver.update_access(context, share, None, None, share_server)
+        self.driver.check_for_setup_error()
+        self.driver.get_network_allocations_number()
+        self.driver._teardown_server(None)
+        self.driver.revert_to_snap_support = True
+        share_access_rules = mock.Mock()
+        snapshot_access_rules = mock.Mock()
+        self.driver.revert_to_snapshot(context, snapshot, share_access_rules,
+                                       snapshot_access_rules, share_server)
+        self.driver.ipv6_implemented = False
+        self.driver.get_configured_ip_versions()
 
     def test_not_support_manage(self):
         share = mock.Mock()
@@ -200,9 +262,23 @@ class EMCShareFrameworkTestCase(test.TestCase):
         result = self.driver.manage_server(None, share_server, identifier,
                                            driver_options)
         self.assertIsInstance(result, NotImplementedError)
+        result = self.driver.get_share_server_network_info(None,
+                                                           share_server,
+                                                           identifier,
+                                                           driver_options)
+        self.assertIsInstance(result, NotImplementedError)
+
+        self.assertRaises(NotImplementedError, self.driver.shrink_share, share,
+                          20, share_server)
+
+        share_access_rules = mock.Mock()
+        snapshot_access_rules = mock.Mock()
+        self.assertRaises(NotImplementedError, self.driver.revert_to_snapshot,
+                          None, snapshot, share_access_rules,
+                          snapshot_access_rules, share_server)
 
     def test_unmanage_manage(self):
-        share = mock.Mock()
+        share = {}
         server_details = {}
         share_server = mock.Mock()
         snapshot = mock.Mock()
